@@ -1,8 +1,7 @@
 # coding: utf-8
 """
-This file contain :
-    - for each range a name associated with for Unicode.
-       --> Scrapped from and (c) https://unicode-table.com/
+This file contain, for each range a name associated with for Unicode.
+Scrapped from https://unicode-table.com/
 """
 UNICODE_RANGES = [
     "0000−001F",
